@@ -31,4 +31,23 @@ void fill (Manager::Config& cfg, const Hash& h) {
     }
 }
 
+void fill (Hash& h, const Manager::Config& cfg) {
+    h["server"]              = xs::out<>(cfg.server);
+    h["min_servers"]         = xs::out<>(cfg.min_servers);
+    h["max_servers"]         = xs::out<>(cfg.max_servers);
+    h["min_spare_servers"]   = xs::out<>(cfg.min_spare_servers);
+    h["max_spare_servers"]   = xs::out<>(cfg.max_spare_servers);
+    h["min_load"]            = xs::out<>(cfg.min_load);
+    h["max_load"]            = xs::out<>(cfg.max_load);
+    h["load_average_period"] = xs::out<>(cfg.load_average_period);
+    h["max_requests"]        = xs::out<>(cfg.max_requests);
+    h["min_worker_ttl"]      = xs::out<>(cfg.min_worker_ttl);
+    h["check_interval"]      = xs::out<>(cfg.check_interval);
+    h["activity_timeout"]    = xs::out<>(cfg.activity_timeout);
+    h["termination_timeout"] = xs::out<>(cfg.termination_timeout);
+    h["force_worker_stop"]   = xs::out<>(cfg.force_worker_stop);
+    h["worker_model"]        = xs::out<>(int(cfg.worker_model));
+    h["bind_model"]          = xs::out<>(int(cfg.bind_model));
+}
+
 }}}
